@@ -106,7 +106,6 @@ class App(dectate.App):
     identity_policy = directive(action.IdentityPolicyAction)
     verify_identity = directive(action.VerifyIdentityAction)
     dump_json = directive(action.DumpJsonAction)
-    load_json = directive(action.LoadJsonAction)
     link_prefix = directive(action.LinkPrefixAction)
 
     def __init__(self):
@@ -338,17 +337,6 @@ class App(dectate.App):
         """
         return False
 
-    def _load_json(self, json, request):
-        """Load JSON as some object.
-
-        By default JSON is loaded as itself.
-
-        :param json: JSON (in Python form) to convert into object.
-        :param request: :class:`morepath.Request`
-        :return: Any Python object, including JSON.
-        """
-        return json
-
     @dispatch_method('obj')
     def _dump_json(self, obj, request):
         """Dump an object as JSON.
@@ -526,8 +514,8 @@ class App(dectate.App):
         """
         def find(app, obj):
             return app._get_mounted_path(obj)
-        info, app = self._follow_defers(find, obj)
-        return info
+
+        return self._follow_defers(find, obj)
 
     def _get_deferred_mounted_class_path(self, model, variables):
         """Path for model and variables taking into account deferring apps.
