@@ -65,21 +65,6 @@ class Request(BaseRequest):
         self.app = self._root_app
         self._after = []
 
-    @reify
-    def body_obj(self):
-        """JSON object, converted to an object.
-
-        You can use the :meth:`App.load_json` directive to specify
-        how to transform JSON to a Python object. By default, no
-        conversion takes place, and ``body_obj`` is identical to
-        the ``json`` attribute.
-        """
-        if not self.body:
-            return None
-        if self.content_type != 'application/json':
-            return None
-        return self.app._load_json(self.json, self)
-
     @reify
     def identity(self):
         """Self-proclaimed identity of the user.
@@ -101,14 +86,22 @@ class Request(BaseRequest):
             return NO_IDENTITY
         return result
 
-    def link_prefix(self):
-        """Prefix to all links created by this request."""
-        cached = self._link_prefix_cache.get(self.app.__class__)
+    def link_prefix(self, app=None):
+        """Prefix to all links created by this request.
+
+        :param app: Optionally use the given app to create the link. This
+        leads to use of the link prefix configured for the given app. This
+        parameter is mainly used internally for link creation.
+
+        """
+        app = app or self.app
+
+        cached = self._link_prefix_cache.get(app.__class__)
         if cached is not None:
             return cached
 
-        prefix = self._link_prefix_cache[self.app.__class__]\
-               = self.app._link_prefix(self)
+        prefix = self._link_prefix_cache[app.__class__]\
+               = app._link_prefix(self)
 
         return prefix
 
@@ -191,12 +184,12 @@ class Request(BaseRequest):
         if app is SAME_APP:
             app = self.app
 
-        info = app._get_deferred_mounted_path(obj)
+        info, app = app._get_deferred_mounted_path(obj)
 
         if info is None:
             raise LinkError("Cannot link to: %r" % obj)
 
-        return info.url(self.link_prefix(), name)
+        return info.url(self.link_prefix(app), name)
 
     def class_link(self, model, variables=None, name='', app=SAME_APP):
         """Create a link (URL) to a view on a class.
